#[non_exhaustive]
pub enum DiffIgnoreWhitespaceSetting {
    None,
    All,
    Change,
}
Configuration option for how to ignore whitespace during diff calculation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

None

Do not ignore whitespace when calculating diffs.

All

Ignore all whitespace in diffs, same as the --ignore-all-space flag.

Change

Ignore changed whitespace in diffs, same as the --ignore-space-change flag.