Provides configuration path utilities.
Functions
- combine
- Combines the specified segments into one path.
- delimiter
- Gets the key delimiter used in configuration paths.
- last
- Extracts the last path segment from the path.
- next
- Extracts the next path segment with a given base.
- parent
- Extracts the path corresponding to the parent node for a given path.
- provider
- Gets the name of a provider from a file path.
- starts_
with - Determines if the given text starts with the provided prefix text.