provider

Function provider 

pub fn provider<'a>(path: &'a Path, name: &'a str) -> &'a str
Gets the name of a provider from a file path.

Arguments

  • path - The path to extract the provider name from
  • name - The default name to use if the path doesn’t have a file name