Crate axvm

Crate axvm 

This crate provides a minimal VM monitor (VMM) for running guest VMs.

This crate contains:

  • AxVM: The main structure representing a VM.

Modules

config
The configuration structure for the VM. The AxVMCrateConfig is generated from toml file, and then converted to AxVMConfig for the VM creation.

Structs

AxVM
A Virtual Machine.
VMMemoryRegion
Represents a memory region in a virtual machine.

Enums

VMStatus
VM status enumeration representing the lifecycle states of a virtual machine

Traits

AxVMHal
The interfaces which the underlying software (kernel or hypervisor) must implement.

Functions

has_hardware_support
Whether the hardware has virtualization support.

Type Aliases

AxVCpuRef
A reference to a vCPU.
AxVMPerCpu
The architecture-independent per-CPU type.
AxVMRef
A reference to a VM.