Configuration

Struct Configuration 

pub struct Configuration { /* private fields */ }
Represents a configuration.

Implementations

Source

impl Configuration

pub fn new( settings: Settings, tokens: impl IntoIterator<Item = Box<dyn ChangeToken>>, providers: Vec<String>, ) -> Self

Initializes a new Configuration.

Arguments
  • settings - The configuration settings
  • tokens - The sequence of change tokens associated with the configuration
  • providers - The names of the providers that generated the configuration
pub fn get(&self, key: &str) -> Option<&str>

Gets a configuration value.

Arguments
  • key - The case-insensitive key of the configuration value to get
pub fn section(&self, key: impl Into<String>) -> Section<'_>

Gets a section in this configuration.

Arguments
  • key - The case-insensitive key of the configuration subsection to get
pub fn sections(&self) -> Vec<Section<'_>>

Gets all of the sections in this configuration.

pub fn change_token(&self) -> impl ChangeToken

Returns a change token that indicates when the configuration has changed.