pub struct FileSource {
pub path: PathBuf,
pub optional: bool,
pub reload_on_change: bool,
}Expand description
Represents a file configuration source.
Fields
path: PathBufGets or sets the source file path.
optional: boolreload_on_change: boolGets or sets a value indicating whether the file will be loaded if the underlying file changes.
Remarks
The default value is false.
Implementations
Sourceimpl FileSource
impl FileSource