ReloadableConfiguration

Struct ReloadableConfiguration 

pub struct ReloadableConfiguration(/* private fields */);
Represents a reloadable configuration.

Implementations

Source

impl ReloadableConfiguration

pub fn new(builder: Builder, configuration: Configuration) -> Self

Initializes a new ReloadableConfiguration.

Arguments
pub fn current(&self) -> Arc<Configuration>

Gets the current configuration.

Remarks

This method will reload the configuration if it has changed. If the reload operation fails, then the error is logged and the previous configuration is retained.

Source

impl ReloadableConfiguration

pub fn reify<T: DeserializeOwned>(&self) -> Result<T>

Available on crate feature binder only.

Creates and returns a structure reified from the configuration.

pub fn bind<T: DeserializeOwned>(&self, instance: &mut T) -> Result

Available on crate feature binder only.

Binds the configuration to the specified instance.

Arguments
  • instance - The instance to bind the configuration to
pub fn bind_at<T: DeserializeOwned>( &self, key: impl AsRef<str>, instance: &mut T, ) -> Result

Available on crate feature binder only.

Binds the specified configuration section to the provided instance.

Arguments
  • key - The key of the configuration section to bind
  • instance - The instance to bind the configuration to
pub fn get_value<T: FromStr>( &self, key: impl AsRef<str>, ) -> Result<Option<T>, T::Err>

Available on crate feature binder only.

Gets a typed value from the configuration.

Arguments
  • key - The key of the value to retrieve
pub fn get_value_or_default<T: FromStr + Default>( &self, key: impl AsRef<str>, ) -> Result<T, T::Err>

Available on crate feature binder only.

Gets an optional, typed value from the configuration.

Arguments
  • key - The key of the value to retrieve