pub struct Section<'a> { /* private fields */ }Expand description
Represents a configuration section.
Implementations
Sourceimpl<'a> Section<'a>
impl<'a> Section<'a>
Sourcepub fn section(&self, key: &str) -> Section<'a>
pub fn section(&self, key: &str) -> Section<'a>
Gets a configuration subsection in this section.
Arguments
key- The case-insensitive key of the configuration subsection to get
Sourcepub fn sections(&self) -> Vec<Section<'a>>
pub fn sections(&self) -> Vec<Section<'a>>
Gets all of the subsections in this section.
Sourcepub fn to_owned(&self) -> OwnedSection
pub fn to_owned(&self) -> OwnedSection
Gets an owned copy of the section.
Remarks
This function is useful for taking ownership of a section in order to decouple it from the entire configuration that created it. The owned section holds a reference to the subset of key/value pairs at this point in the configuration.