puzzled
puzzled is a library for creating and managing a network of nodes.
Re-exports
pub use super::BoxError;pub use super::BoxResult;pub use super::Result;pub use super::action::*;pub use super::conduit::*;pub use super::handle::*;pub use super::stateful::*;pub use super::platform::*;pub use super::power::*;pub use super::stage::*;pub use super::timestamp::*;
Modules
Structs
Enums
Constants
- APP_
NAME - The name of the application.
- ARTIFACTS
- The name of the artifacts directory.
- DEFAULT_
CONFIG_ DIR - The default location for the configuration directory.
- DEFAULT_
CONTEXT - DEFAULT_
HOST - DEFAULT_
PORT - The default port for the application.
- DEFAULT_
WORKDIR - LOCALHOST
- A str constant for the localhost address.
Functions
- graceful_
shutdown - std_
time - systime
- systime is a utilitarian function that returns the current system time in milliseconds.
- timestamp