Settings

Struct Settings 

pub struct Settings(/* private fields */);
Represents a case-insensitive collection of configuration settings.

Implementations

Source

impl Settings

pub fn new() -> Self

Initializes new Settings.

pub fn len(&self) -> usize

Gets the number of settings.

pub fn is_empty(&self) -> bool

Gets a value indicating whether the collection is empty.

pub fn keys(&self) -> Keys<'_>

Gets an iterator over the keys in the collection in an arbitrary order.

pub fn get(&self, key: &str) -> Option<&str>

Gets the setting with the specified key.

Arguments
  • key - The case-insensitive key of the setting to retrieve
pub fn insert( &mut self, key: impl Into<String>, value: impl Into<String>, ) -> Option<String>

Adds or updates a setting with the specified key and value.

Arguments
  • key - The key of the setting to add or update
  • value - The value of the setting to add or update
pub fn shrink_to_fit(&mut self)

Shrinks the capacity of the settings as much as possible. It will drop down as much as possible while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.