stateset-sync
Event-sourcing sync engine for StateSet iCommerce.
Provides the core sync primitives for managing network state between local SQLite stores and the remote VES sequencer:
- Outbox – append-only event log for recording local mutations
- EventBuffer – bounded FIFO buffer for pulled remote events
- ConflictResolver – pluggable strategies (
RemoteWins,LocalWins,LastWriterWins) - Transport – async trait abstracting push/pull over any network protocol
- SyncEngine – orchestrator tying outbox, buffer, conflict resolution, and transport together
Modules
event– TheSyncEventtype representing state changesoutbox– Append-only eventOutboxfor recording local eventsbuffer– Bounded FIFOEventBufferfor pulled eventsconflict–ConflictResolverwith pluggable strategiestransport– AsyncTransporttrait for push/pullengine– The mainSyncEngineorchestratorconfig–SyncConfigfor engine configurationstate–SyncStateandSyncStatustypeserror–SyncErrorerror type
Re-exports
pub use buffer::EventBuffer;pub use config::SyncConfig;pub use conflict::ConflictResolver;pub use conflict::ConflictStrategy;pub use conflict::Resolution;pub use engine::SyncEngine;pub use error::SyncError;pub use event::SyncEvent;pub use outbox::Outbox;pub use state::SyncState;pub use state::SyncStatus;pub use transport::NullTransport;pub use transport::PullPage;pub use transport::PullResult;pub use transport::PushResult;pub use transport::Transport;