Merge

Trait Merge 

pub trait Merge<T = Self> {
    // Required method
    fn merge(&mut self, other: &T);
}
Defines the behavior of a merge operation between two objects.

Required Methods

fn merge(&mut self, other: &T)

Merges an object into current object.

Arguments
  • other - The other object to merge into the current object

Implementors