pub trait Reloadable: Sized {
// Required methods
fn can_reload(&self) -> bool;
fn reload_token(&self) -> impl ChangeToken + 'static;
}Expand description
Defines the behavior of a reloadable configuration.
Required Methods
Sourcefn can_reload(&self) -> bool
fn can_reload(&self) -> bool
Gets a value indicating whether the configuration can be reloaded.
Sourcefn reload_token(&self) -> impl ChangeToken + 'static
fn reload_token(&self) -> impl ChangeToken + 'static
Gets a change token that will be notified when the configuration is reloaded.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".