This library provides utilities for integrating with Packrinth. For example,
the module config gives structs for reading and editing Packrinth configuration files.
The module modrinth can be used to retrieve data from Modrinth and convert it to
Packrinth-compatible structs.
If you just want to use the Packrinth CLI, go to https://thijzert123.github.io/packrinth to see how to use it.
Modules
- config
- Structs for configuring and managing a Packrinth modpack instance.
- modrinth
- Structs that are only used for (de)serializing JSONs associated with Modrinth.
Enums
- Packrinth
Error - An error that can occur while performing Packrinth operations.
Functions
- extract_
mrpack - Extract all the contents of a Modrinth modpack, except for the main manifest file.
- modpack_
is_ dirty - Checks if the modpack is dirty.