pub fn provider<'a>(path: &'a Path, name: &'a str) -> &'a strExpand description
Gets the name of a provider from a file path.
Arguments
path- The path to extract the provider name fromname- The default name to use if the path doesn’t have a file name