pub struct Configuration { /* private fields */ }Expand description
Represents a configuration.
Implementations
Sourceimpl Configuration
impl Configuration
Sourcepub fn new(
settings: Settings,
tokens: impl IntoIterator<Item = Box<dyn ChangeToken>>,
providers: Vec<String>,
) -> Self
pub fn new( settings: Settings, tokens: impl IntoIterator<Item = Box<dyn ChangeToken>>, providers: Vec<String>, ) -> Self
Initializes a new Configuration.
Arguments
settings- The configuration settingstokens- The sequence of change tokens associated with the configurationproviders- The names of the providers that generated the configuration
Sourcepub fn get(&self, key: &str) -> Option<&str>
pub fn get(&self, key: &str) -> Option<&str>
Gets a configuration value.
Arguments
key- The case-insensitive key of the configuration value to get
Sourcepub fn section(&self, key: impl Into<String>) -> Section<'_>
pub fn section(&self, key: impl Into<String>) -> Section<'_>
Gets a section in this configuration.
Arguments
key- The case-insensitive key of the configuration subsection to get
Sourcepub fn change_token(&self) -> impl ChangeToken
pub fn change_token(&self) -> impl ChangeToken
Returns a change token that indicates when the configuration has changed.