Struct config::PrivatEmailConfig [−][src]
Config object for PrivatEmail.
Implements serde::Deserialize and serde::Serialize and
can be composed with other consumer configs.
PrivatEmailConfig:
from_email: Forwarded emails will be received from this SES verified email address.
To match all email addresses on a domain, use a key without the name part of the email(example.com)
to_email: Recipient email address. Example: jon@doe.example
subject_prefix: Forwarded emails subject will contain this prefix.
email_bucket: S3 bucket to store raw SES emails.
email_key_prefix: S3 key prefix where SES stores emails.
Fields
from_email: StringForwarded emails will be received from this SES verified email address
to_email: StringRecipient email address that receives the forwarded SES email
subject_prefix: Option<String>Forwarded emails subject will contain this prefix
email_bucket: Option<String>S3 bucket to store raw SES emails
email_key_prefix: Option<String>S3 key prefix where SES stores emails
Implementations
impl PrivatEmailConfig[src]
Create a new PrivatEmailConfig client struct from environment variables.
pub fn new_from_env() -> Self[src]
Create new PrivatEmailConfig struct from environment variables.
As long as you have the from_email and to_email environment setup; this should work
pub fn new<F, T, S>(from_email: F, to_email: T, subject_prefix: S) -> Self where
F: ToString,
T: ToString,
S: ToString, [src]
F: ToString,
T: ToString,
S: ToString,
Create a new PrivatEmailConfig struct.PrivatEmailConfig You can leave the s3 bucket related fields empty since it’s not currently being used