pub struct PrivatEmailConfig {
    pub from_email: String,
    pub to_email: String,
    pub black_list: Option<Vec<String>>,
}
Config object for PrivatEmail.

Implements serde::Deserialize and serde::Serialize and can be composed with other consumer configs. PrivatEmailConfig: from_email: Original Recipient Email from Verified SES Domain to_email: Recipient SES verified email address which receives the forwarded email black_list: Black listed email addresses.

Fields

from_email: String

Original Recipient Email from Verified SES Domain

to_email: String

Recipient email address that receives the forwarded SES email

black_list: Option<Vec<String>>

Black Listed email addresses

Implementations

Create a new PrivatEmailConfig client struct from environment variables.

Create new PrivatEmailConfig struct from environment variables.

Create a new PrivatEmailConfig struct