pub struct ReloadableConfiguration(/* private fields */);Expand description
Represents a reloadable configuration.
Implementations
Sourceimpl ReloadableConfiguration
impl ReloadableConfiguration
Sourcepub fn new(builder: Builder, configuration: Configuration) -> Self
pub fn new(builder: Builder, configuration: Configuration) -> Self
Initializes a new ReloadableConfiguration.
Arguments
builder- The builder used to reload the configurationconfig- The initial configuration
Sourcepub fn current(&self) -> Arc<Configuration>
pub fn current(&self) -> Arc<Configuration>
Gets the current configuration.
Remarks
This method will reload the configuration if it has changed. If the reload operation fails, then the error is logged and the previous configuration is retained.
Sourceimpl ReloadableConfiguration
impl ReloadableConfiguration
Sourcepub fn reify<T: DeserializeOwned>(&self) -> Result<T>
Available on crate feature binder only.
pub fn reify<T: DeserializeOwned>(&self) -> Result<T>
binder only.Creates and returns a structure reified from the configuration.
Sourcepub fn bind<T: DeserializeOwned>(&self, instance: &mut T) -> Result
Available on crate feature binder only.
pub fn bind<T: DeserializeOwned>(&self, instance: &mut T) -> Result
binder only.Binds the configuration to the specified instance.
Arguments
instance- The instance to bind the configuration to
Sourcepub fn bind_at<T: DeserializeOwned>(
&self,
key: impl AsRef<str>,
instance: &mut T,
) -> Result
Available on crate feature binder only.
pub fn bind_at<T: DeserializeOwned>( &self, key: impl AsRef<str>, instance: &mut T, ) -> Result
binder only.Binds the specified configuration section to the provided instance.
Arguments
key- The key of the configuration section to bindinstance- The instance to bind the configuration to