pub struct Settings(/* private fields */);Expand description
Represents a case-insensitive collection of configuration settings.
Implementations
Sourceimpl Settings
impl Settings
Sourcepub fn keys(&self) -> Keys<'_>
pub fn keys(&self) -> Keys<'_>
Gets an iterator over the keys in the collection in an arbitrary order.
Sourcepub fn get(&self, key: &str) -> Option<&str>
pub fn get(&self, key: &str) -> Option<&str>
Gets the setting with the specified key.
Arguments
key- The case-insensitive key of the setting to retrieve
Sourcepub fn insert(
&mut self,
key: impl Into<String>,
value: impl Into<String>,
) -> Option<String>
pub fn insert( &mut self, key: impl Into<String>, value: impl Into<String>, ) -> Option<String>
Adds or updates a setting with the specified key and value.
Arguments
key- The key of the setting to add or updatevalue- The value of the setting to add or update
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the settings as much as possible. It will drop down as much as possible while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.